@@ -23,31 +23,33 @@ with open('%s%d.json' % (path, shotn), 'r') as file:
     data = json.load(file)
     x = []
     T_c = []
+    T_err = []
     n_c = []
     for event in data['events']:
         if 'T_e' in event and 'T' in event['T_e'][poly]:
             x.append(event['timestamp'] * 1e-3)
             T_c.append(event['T_e'][poly]['T'])
+            T_err.append(event['T_e'][poly]['Terr'])
             n_c.append(event['T_e'][poly]['n'])
 
-path = 'D:/tmp/'
+
 to_pack = {
     'central Te': {
         'comment': 'Температура в центре',
         'unit': 'T_e(eV)',
-        'timestamp': time.time(),  # not required
         'x': x,
-        'y': T_c
+        'y': T_c,
+        'err': T_err
     },
     'signal 2': {
-        'comment': 'Температура в центре',
+        'comment': 'ne в центре',
         'unit': 'T_e(eV)',
         'x': x,
-        'y': T_c
+        'y': n_c
     }
 }
 
-packed = ripper.write(path=path, filename='TS_%d.SHT' % shotn, data=to_pack)
+packed = ripper.write(path='D:/tmp/', filename='TS_%d.SHT' % shotn, data=to_pack)
 if len(packed) != 0:
     print('packed error = "%s"' % packed)
 
